@@ -1032,7 +1032,8 @@ class Update(MethodsInterface):
         deo = self.get_default_emerge_opts(depclean=True)
         emerge = None
         try:
-            emerge = EmergeParser(EmergeCommand(["--depclean"],
+            emerge = EmergeParser(EmergeCommand(["--depclean",
+                                                 "--dynamic-deps=n"],
                                                 emerge_default_opts=deo))
             outdated_kernel = False
             try:
